@@ -31,7 +31,7 @@ import gtk.glade
 
 from debconf import DebconfCommunicator
 
-from oem_config import filteredcommand, i18n
+from oem_config import filteredcommand, i18n, zoommap
 from oem_config.components import console_setup, language, timezone, user, \
                                   language_apply, timezone_apply, \
                                   console_setup_apply
@@ -118,8 +118,17 @@ class Frontend:
 
         self.translate_widgets()
 
-        self.tzmap = TimezoneMap(self)
-        self.tzmap.tzmap.show()
+        if 'UBIQUITY_OLD_TZMAP' in os.environ:
+            self.tzmap = TimezoneMap(self)
+            self.tzmap.tzmap.show()
+        else:
+            pixmap = '/usr/share/oem-config/pixmaps/earth.jpg'
+            full_zoom = True
+            font_selected = "white"
+            font_unselected = "orange"
+            args = (self, pixmap, full_zoom, font_selected, font_unselected)
+            self.tzmap = zoommap.ZoomMapWidget(*args)
+            self.tzmap.show()
 
         if 'OEM_CONFIG_DEBUG' in os.environ:
             self.password_debug_warning_label.show()
@@ -229,6 +238,13 @@ class Frontend:
 
         self.oem_config.hide()
 
+    def set_window_hints(self, widget):
+        if 'OEM_CONFIG_ONLY' in os.environ:
+            # Disable minimise button.
+            widget.window.set_functions(
+                gtk.gdk.FUNC_RESIZE | gtk.gdk.FUNC_MOVE |
+                gtk.gdk.FUNC_MAXIMIZE)
+
     # Internationalisation.
 
     def translate_widgets(self):
@@ -352,6 +368,7 @@ class Frontend:
     def set_current_page(self, current):
         global BREADCRUMB_STEPS, BREADCRUMB_MAX_STEP
         self.current_page = current
+        self.translate_widget(self.step_label, self.locale)
         if current == 0:
             self.back.hide()
         else:
@@ -408,6 +425,9 @@ class Frontend:
             # expect recursive main loops to be exited and
             # debconffilter_done() to be called when the filter exits
 
+        if not self.oem_config.get_focus():
+            self.oem_config.child_focus(gtk.DIR_TAB_FORWARD)
+
     def on_next_clicked(self, widget):
         if not self.allowed_change_step or not self.allowed_go_forward:
             return
@@ -425,6 +445,9 @@ class Frontend:
             # expect recursive main loops to be exited and
             # debconffilter_done() to be called when the filter exits
 
+        if not self.oem_config.get_focus():
+            self.oem_config.child_focus(gtk.DIR_TAB_FORWARD)
+
     # Callbacks provided to components.
 
     def selected_language(self, selection):
@@ -468,7 +491,7 @@ class Frontend:
             return 'C'
         else:
             value = unicode(model.get_value(iterator, 0))
-            return self.language_choice_map[value][0]
+            return self.language_choice_map[value][1]
 
     def on_language_treeview_row_activated(self, treeview, path, view_column):
         self.next.activate()
@@ -602,6 +625,9 @@ class Frontend:
     def get_verified_password(self):
         return self.verified_password.get_text()
 
+    def get_auto_login(self):
+        return self.auto_login.get_active()
+
     def username_error(self, msg):
         self.username_error_reason.set_text(msg)
         self.username_error_box.show()
