@@ -26,6 +26,8 @@ import datetime
 import gettext
 import syslog
 
+from PyKDE4.kdecore import ki18n, KAboutData, KCmdLineArgs
+from PyKDE4.kdeui import KApplication, KMainWindow, KIcon
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 from PyQt4 import uic
@@ -53,18 +55,14 @@ class OEMConfUI(QWidget):
     def __init__(self, parent):
         QWidget.__init__(self, parent)
         uic.loadUi("%s/sysconf.ui" % UIDIR, self)
-        self.setWindowState(Qt.WindowFullScreen)
+        self.setAutoFillBackground(True)
 
     def setFrontend(self, fe):
         self.frontend = fe
 
     def resizeEvent(self, event):
-        if QFile.exists("/usr/lib/kde4/share/wallpapers/EOS/contents/images/1920x1200.jpg"):
-            imageFile = "/usr/lib/kde4/share/wallpapers/EOS/contents/images/1920x1200.jpg"
-        elif QFile.exists("/usr/share/wallpapers/kubuntu-wallpaper.png"):
-            imageFile = "/usr/share/wallpapers/kubuntu-wallpaper.png"
-        elif QFile.exists("/usr/share/wallpapers/kubuntu-wallpaper.jpg"):
-            imageFile = "/usr/share/wallpapers/kubuntu-wallpaper.jpg"
+        if QFile.exists("/usr/share/wallpapers/Blue_Curl/contents/images/1920x1200.jpg"):
+            imageFile = "/usr/share/wallpapers/Blue_Curl/contents/images/1920x1200.jpg"
         else:
             return
         pixmapUnscaled = QPixmap()
@@ -98,17 +96,46 @@ class Frontend:
         self.allowed_go_forward = True
         self.mainLoopRunning = False
         self.apply_changes = False
-        self.app = QApplication([])
-        self.app.setStyle(QStyleFactory.create("Plastique"))
+
+        appName = "oem-config"
+        catalog = ""
+        programName = ki18n("OEM Config")
+        version = "1.0"
+        description = ki18n("Sets up the system")
+        license = KAboutData.License_GPL
+        copyright = ki18n("2006, 2007 Anirudh Ramesh. 2008 Canonical Ltd.")
+        text = ki18n("none")
+        homePage = "http://www.kubuntu.org"
+        bugEmail = ""
+
+        aboutData = KAboutData(appName, catalog, programName, version, description,
+                               license, copyright, text, homePage, bugEmail)
+
+        KCmdLineArgs.init(['oem-config', '-style=oxygen'], aboutData)
+
+        self.app = KApplication()
         # We want to hide the minimise button if running in the ubiquity-only mode (no desktop)
         # To achieve this we need to set window flags to Dialog but we also need a parent widget which is showing
         # else Qt tried to be clever and puts the minimise button back
         self.parentWidget = QWidget()
         self.parentWidget.show()
-        self.userinterface = OEMConfUI(self.parentWidget)
-        self.userinterface.setWindowFlags(Qt.Dialog)
+
+        # The parent for our actual user interface window, this is needed only because Oxygen widget 
+        # style refuses to draw our background on a top level widget
+        self.parent2 = QWidget(self.parentWidget)
+        self.parent2.setAutoFillBackground(True)
+        self.parent2.setWindowState(Qt.WindowFullScreen)
+        self.parent2.setWindowFlags(Qt.Dialog)
+        layout = QVBoxLayout(self.parent2)
+        layout.setContentsMargins(0, 0, 0, 0)
+
+        self.userinterface = OEMConfUI(self.parent2)
         self.userinterface.setFrontend(self)
-        self.userinterface.show()
+        layout.addWidget(self.userinterface)
+        self.parent2.show()
+
+        self.userinterface.next.setIcon(KIcon("go-next"))
+        self.userinterface.back.setIcon(KIcon("go-previous"))
 
         self.translate_widgets()
 
@@ -267,6 +294,15 @@ class Frontend:
 
         text = self.get_string(name, lang)
 
+        if str(name) == 'language_label':
+            text = self.get_string('language_heading_label', lang)
+
+        if str(name) == 'next':
+            text = self.get_string('oem-config/imported/go-forward', lang)
+
+        if str(name) == 'back':
+            text = self.get_string('oem-config/imported/go-back', lang)
+
         if str(name) == "SysConf":
             text = self.get_string("oem_config", lang)
 
@@ -285,15 +321,11 @@ p, li { white-space: pre-wrap; }
 p, li { white-space: pre-wrap; }
 </style></head><body style=" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;">
 <p style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-style:italic;">""" +
-                               text + "</span></p></body></html>")
+                               text + "</span></p></body></html>")                
             else:
                 widget.setText(text)
 
         elif isinstance(widget, QPushButton):
-            if name == 'next':
-                text = text + " >"
-            elif name == 'back':
-                text = "< " + text
             widget.setText(text.replace('_', '&', 1))
 
         elif isinstance(widget, QWidget) and str(name) == "SysConf":
@@ -347,7 +379,7 @@ p, li { white-space: pre-wrap; }
 
     def get_language(self):
         value = unicode(self.userinterface.language_list.currentItem().text())
-        return self.language_choice_map[value][0]
+        return self.language_choice_map[value][1]
 
     def on_language_treeview_selection_changed(self):
         lang = self.selected_language()
@@ -355,7 +387,7 @@ p, li { white-space: pre-wrap; }
             global WIDGET_STACK_MAX_STEPS
             # strip encoding; we use UTF-8 internally no matter what
             lang = lang.split('.')[0].lower()
-            for widget in (self.userinterface, self.userinterface.language_label, self.userinterface.back, self.userinterface.next):
+            for widget in (self.userinterface, self.userinterface.language_label, self.userinterface.welcome_label, self.userinterface.back, self.userinterface.next):
                 self.translate_widget(widget, lang)
             for step in range(WIDGET_STACK_MAX_STEPS + 1):
                 self.translate_widget(self.step_labels[step], lang)
@@ -421,6 +453,9 @@ p, li { white-space: pre-wrap; }
     def get_verified_password(self):
         return unicode(self.userinterface.pass_ledit_2.text())
 
+    def get_auto_login(self):
+        return False
+
     def watch_debconf_fd (self, from_debconf, process_input):
         self.debconf_fd_counter = 0
         self.socketNotifierRead = QSocketNotifier(from_debconf, QSocketNotifier.Read, self.app)
@@ -518,9 +553,10 @@ p, li { white-space: pre-wrap; }
         else:
             self.userinterface.back.show()
         if current_name == 'step_user':
-            self.userinterface.next.setText(QApplication.translate("SysConf", "&Finish!", None, QApplication.UnicodeUTF8))
+            #FIXME needs i18n(Finish)
+            self.userinterface.next.setIcon(KIcon("dialog-ok"))
         else:
-            self.userinterface.next.setText(QApplication.translate("SysConf", "&Continue >", None, QApplication.UnicodeUTF8))
+            self.userinterface.next.setIcon(KIcon("go-next"))
         for icon in self.step_icons:
             pixmap = QIcon(icon.pixmap()).pixmap(self.step_icon_size, QIcon.Disabled)
             icon.setPixmap(pixmap)
